#/bin/sh
# jpsb: September 2015
# A shell script to easily change the OneStepBack theme colors
# The script needs sed and ImageMagick
# Usage:
#       1 uncomment a group of colors below or create a new one
#       2 open a terminal in the OneStepBack directory
#       3 run "sh OSBmod.sh"

## lighter version of grays
#lighter_color="#ededed"
#base_color="#cacaca"
#darker_color="#9e9e9e"
#selected_color="#2e5c83"

## more windowish colors
#lighter_color="#eeeeee"
#base_color="#d6d3ce"
#darker_color="#a3a19d"
#selected_color="#08246b"

## resetting to original colors:
#lighter_color="#c8c8c8"
#base_color="#a8a8a8"
#darker_color="#787878"
#selected_color="#4b6983"

# =============================================================
# You do not need to change anything else. Just run the script.
# =============================================================

# test if colors are set
if [[ $lighter_color == "" ]] | [[ $base_color == "" ]] | [[ $darker_color == "" ]] | [[ $selected_color == "" ]]
then
    echo "One color at least is not set."
    echo "Please edit the script and uncomment or create a group of colors."
    echo "No change done."
    exit 1
fi

# change colors in text files
sed -i "s/@define-color base_color .\+;/@define-color base_color $base_color;/g" gtk-3.0/gtk.css
sed -i "s/base_color:.\+/base_color:$base_color/g" gtk-2.0/gtkrc

sed -i "s/@define-color lighter_color .\+;/@define-color lighter_color $lighter_color;/g" gtk-3.0/gtk.css
sed -i "s/lighter_color:.\+/lighter_color:$lighter_color/g" gtk-2.0/gtkrc

sed -i "s/@define-color darker_color .\+;/@define-color darker_color $darker_color;/g" gtk-3.0/gtk.css
sed -i "s/darker_color:.\+/darker_color:$darker_color/g" gtk-2.0/gtkrc

sed -i "s/@define-color selected_color .\+;/@define-color selected_color $selected_color;/g" gtk-3.0/gtk.css
sed -i "s/selected_color:.\+/selected_color:$selected_color/g" gtk-2.0/gtkrc

# change colors in image files
mogrify -fill "$base_color" -draw 'color 30,5 replace' img/scrollbar_horizontal.png

mogrify -fill "$base_color" -draw 'color 5,30 replace' img/scrollbar_vertical.png

mogrify -fill "$lighter_color" -draw 'color 30,5 replace' img/scrollbar_horizontal_prelight.png

mogrify -fill "$lighter_color" -draw 'color 5,30 replace' img/scrollbar_vertical_prelight.png

# modify name
sed -i "s/OneStepBack\n/OneStepBack_modified\n/g" index.theme

# add special README
echo "This is the OneStepBack theme modified by OSBmod.sh." > README_modified

# echo changes done
echo "Done."
